@@ -10,7 +10,7 @@ from apport.hookutils import *
 LOG_FILE = os.path.expanduser('~/.cache/simple-scan/simple-scan.log')
 driver_packages = ['libsane', 'libsane-extras', # SANE drivers
                    'hplip', 'hpoj', # HP drivers
-                   'iscan', 'iscan-data', 'iscan-network-nt', # Espon drivers
+                   'iscan', 'iscan-data', 'iscan-network-nt', # Epson drivers
                    'brscan', 'brscan2', 'brscan3', 'brscan4' # Brother drivers
                   ]
 
